#!/usr/bin/env node --harmony

import program from 'commander';
import updateNotifier from 'update-notifier';

program.version('1.0.7');

const pkg = require('../package.json');

updateNotifier({pkg}).notify();

program.command('init').description('?').action(() => {
	const init = require('./commands/init');
	init();
});

program.command('sync').description('?').action(() => {
	const sync = require('./commands/sync');
	sync();
});

program.command('optimize').description('?').action(() => {
	const optimize = require('./commands/optimize');
	optimize();
});

program.command('deploy').description('?').action(() => {
	const deploy = require('./commands/deploy');
	deploy();
});

program.command('server').description('?')
	.option('-p, --port <n>', 'custom port', parseInt)
	.action(args => {
		const server = require('./commands/server');
		server(args);
	});

program.parse(process.argv);

if (process.argv.slice(2).length === 0) {
	console.log(`
  Usage
    $ blinkloader <command>

  where <command> is one of:
    optimize, server, deploy, sync, init

  Quick help on <command>
    $ blinkloader <command> --help

  Examples
    $ blinkloader init
    $ blinkloader optimize
    $ blinkloader sync
    $ blinkloader server
    $ blinkloader server --port 3000
    $ blinkloader deploy

  `);
}
