import exit from 'exit';
import inquirer from 'inquirer';

import {n, log, error, gray, errorExit} from '../../utils/decorators';
import Config from '../../utils/config';
import staticWebsiteViaS3 from './static-website-via-s3';

const SUPPORTED_DEPLOYMENTS = ['static-website-via-s3'];

const config = new Config('./blinkloader.json');

const runDeployment = clientConfig => {
	const clientStack = config.getStack();
	n();
	log('stack: ' + gray(clientStack));
	n();

	if (!SUPPORTED_DEPLOYMENTS.includes(clientStack)) {
		error('we don\'t have a deployment solution for your stack at the moment');
		n();
		exit();
	}

	if (clientStack === 'static-website-via-s3') {
		staticWebsiteViaS3(clientConfig);
	}
};

const deploy = () => {
	if (config.get() === null) {
		n();
		errorExit('no blinkloader.json file in project directory, generate it with ' + gray('blinkloader init') + ' command');
	}

	const stepsAfterConfirmation = () => {
		const questions = [];
		const domains = config.getDomains();

		if (domains.length === 0) {
			n();
			errorExit('no domains found, please specify at least one domain in blinkloader.json to deploy');
		}

		if (domains.length > 1) {
			questions.push({
				type: 'list',
				name: 'domain',
				message: 'We\'ve identified multiple domains in the configuration. Where would you like to deploy?',
				choices: domains
			});

			inquirer.prompt(questions).then(answers => {
				runDeployment(answers);
			});
		} else {
			runDeployment({domain: domains[0]});
		}
	};

	const initialQuestions = [];

	if (config.getStack() === 'static-website-via-s3') {
		initialQuestions.push({
			name: 'confirmation',
			type: 'confirm',
			message: 'S3 deployment will use your AWS credentials and change the content of buckets\n having same names as domains. Would you like to proceed?'
		});
	}

	if (initialQuestions.length > 0) {
		inquirer.prompt(initialQuestions).then(answers => {
			if (answers.confirmation === false) {
				n();
				log('Deployment was cancelled. Let us know how to make the experience better:');
				log(`${gray('https://github.com/blinkloader/blinkloader/issues/new')}`);
				n();
				exit();
			} else {
				stepsAfterConfirmation();
			}
		});
	} else {
		stepsAfterConfirmation();
	}
};

module.exports = deploy;
