import zlib from 'zlib';
import fs from 'fs';

const exts = ['.js', '.css', '.html', '.htm', '.png', '.jpg', '.jpeg', '.gif'];

const toGzip = name => {
	for (let i = 0; i < exts.length; i++) {
		if (name.endsWith(exts[i])) {
			return true;
		}
	}
	return false;
};

export default config => new Promise((resolve, reject) => {
	if (config.config.getOptimizations().indexOf('gzip') === -1) {
		return resolve(config);
	}
	const readyPromises = [];
	config.config.walkDir(config.config.getSiteOptimizedDir()).forEach(file => {
		readyPromises.push(new Promise((resolve, reject) => {
			if (!toGzip(file)) {
				return resolve();
			}
			try {
				zlib.gzip(fs.readFileSync(file), (err, result) => {
					if (err) {
						reject(err);
					}
					fs.writeFileSync(file, result);
					resolve();
				});
			} catch (err) {
				reject(config.decorators.error('compressing file: ' + file + ': ' + err));
			}
		}));
	});
	return Promise.all(readyPromises)
		.then(() => resolve(config))
		.catch(err => reject(err));
});

