import fs from 'fs';
import compressor from 'node-minify';
import {minify} from 'html-minifier';

export default config => new Promise((resolve, reject) => {
	if (config.config.getOptimizations().indexOf('minify') === -1) {
		return resolve(config);
	}
	const readyPromises = [];
	config.assets.forEach(asset => {
		const assetSplitted = asset.split('.');
		if (assetSplitted[assetSplitted.length - 1] === 'js') {
			readyPromises.push(new Promise(resolve => {
				compressor.minify({
					compressor: 'babili',
					input: config.config.getSiteDir() + asset,
					output: config.config.getSiteOptimizedDir() + asset
				}).then(() => {
					config.decorators.checkbox(`minified ${config.decorators.gray(asset)}`);
					resolve();
				}).catch(err => {
					config.decorators.error('minifying ' + asset + ': ' + err);
					resolve();
				});
			}));
		} else if (assetSplitted[assetSplitted.length - 1] === 'css') {
			readyPromises.push(new Promise(resolve => {
				compressor.minify({
					compressor: 'clean-css',
					input: config.config.getSiteDir() + asset,
					output: config.config.getSiteOptimizedDir() + asset,
					options: {
						advanced: false,
						aggressiveMerging: false
					}
				}).then(() => {
					config.decorators.checkbox(`minified ${config.decorators.gray(asset)}`);
					resolve();
				}).catch(err => {
					config.decorators.error('minifying ' + asset + ': ' + err);
					resolve();
				});
			}));
		}
	});
	config.pages.forEach(page => {
		readyPromises.push(new Promise(resolve => {
			try {
				const min = minify(fs.readFileSync(config.config.getSiteOptimizedDir() + page, 'utf-8'), {
					minifyJS: true,
					minifyCSS: true,
					collapseWhitespace: true,
					collapseBooleanAttributes: true,
					removeAttributeQuotes: true,
					removeEmptyAttributes: true,
					removeCDATASectionsFromCDATA: true,
					removeComments: true
				});
				fs.writeFileSync(config.config.getSiteOptimizedDir() + page, min);
				resolve();
			} catch (err) {
				config.decorators.error('minifying ' + page + ': ' + err);
				resolve();
			}
		}));
	});
	return Promise.all(readyPromises)
		.then(() => resolve(config))
		.catch(err => reject(err));
});
