import fs from 'fs';
import archiver from 'archiver';
import ProgressBar from 'progress';
import {BLINKLOADER_API_URL} from '../../env';

const FormData = require('form-data');
const splitFile = require('split-file');

// Prepare optimization: archive site dir, send it to the api endpoint
export default config => new Promise((resolve, reject) => {
	config.decorators.message(config.decorators.yellow('INFO') + '      ', 'archiving optimization targets and sending to Blinkloader');
	const dirAr = fs.createWriteStream(config.config.getSiteArchive());
	const archive = archiver('zip', {
		zlib: {level: 9}
	});
	archive.pipe(dirAr);
	archive.glob(config.config.getSiteDir() + '/**/*.+(html|htm|jpg|jpeg|png|gif|svg|js|css)');
	archive.on('error', err => {
		reject(err);
	});
	dirAr.on('close', () => {
		splitFile.splitFileBySize(config.config.getSiteArchive(), 4e6).then(parts => {
			const bar = new ProgressBar('              uploading [:bar] :percent', {
				total: parts.length + 1,
				complete: '=',
				incomplete: ' ',
				width: 20
			});
			const uploadedParts = [];
			parts.forEach((part, i) => {
				uploadedParts.push(new Promise((resolve, reject) => {
					const form = new FormData();
					form.append('api-key', config.config.getApiKey());
					form.append('project-id', config.projectID);
					form.append('part', i + 1);
					form.append('ar', fs.createReadStream(part));

					config.fetch(`${BLINKLOADER_API_URL}/ar`, {
						method: 'POST',
						headers: form.getHeaders(),
						body: form
					}).then(res => {
						bar.tick();
						if (res.status === 200) {
							return res.json();
						}
						reject(config.decorators.apiCallError('preparing optimization', res.statusText));
					}).then(json => {
						if (json.errorMessage) {
							reject(config.decorators.error('preparing optimization: ' + json.errorMessage));
						}
						config.config.removeFile(config.config.blinkloaderDir() + '/' + part, () => resolve());
					}).catch(err => {
						reject(config.decorators.error('preparing optimization: ' + err));
					});
				}));
			});
			Promise.all(uploadedParts).then(() => {
				config.fetch(`${BLINKLOADER_API_URL}/optimization/prepare?api-key=${config.config.getApiKey()}&project-id=${config.projectID}`).then(res => {
					bar.tick();
					if (bar.complete) {
						config.decorators.n();
					}
					if (res.status === 200) {
						return res.json();
					}
					reject(config.decorators.apiCallError('preparing optimization', res.statusText));
				}).then(json => {
					if (json.errorMessage) {
						reject(config.decorators.error('preparing optimization: ' + json.errorMessage));
					}
					resolve(config);
				}).catch(err => {
					reject(config.decorators.error('preparing optimization: ' + err));
				});
			}).catch(err => reject(err));
		});
	});
	archive.finalize();
});
