import fetch from 'node-fetch';

import {n, info, checkbox, gray, errorExit} from '../../utils/decorators';
import {BLINKLOADER_API_URL} from '../../env';
import Config from '../../utils/config';
import {validateUrl} from '../../utils/utils';

const sync = () => {
	const config = new Config('./blinkloader.json');

	n();

	if (config.get() === null) {
		errorExit('no blinkloader.json file in project directory, generate it with ' + gray('blinkloader init') + ' command');
	}

	const projectId = config.getProjectId();

	const resources = config.getResourceWhitelist();
	if (!resources) {
		errorExit(`no ${gray('resourceWhitelist')} field in ${gray('blinkloader.json')}`);
	}

	const domains = config.getDomains();
	if (!domains) {
		errorExit(`no ${gray('domains')} field in ${gray('blinkloader.json')}`);
	}

	info('reading blinkloader.json');

	resources.forEach(r => {
		if (!validateUrl(r) && r !== '*') {
			errorExit(`invalid url ${r} in resourceWhitelist`);
		}
	});

	domains.forEach(r => {
		if (!validateUrl(r)) {
			errorExit(`invalid url ${r} in domains`);
		}
	});

	checkbox(`validated resources: ${resources}`);
	checkbox(`validated domains: ${domains}`);

	fetch(`${BLINKLOADER_API_URL}/sync`, {
		method: 'POST',
		body: JSON.stringify({
			'resource-whitelist': resources,
			domains,
			'project-id': projectId
		}),
		headers: {
			'Content-Type': 'application/json',
			Authorization: `token ${config.getApiKey()}`
		}
	}).then(res => {
		if (res.status === 200) {
			return res.json();
		}
		errorExit(`error sendind sync request: ${res.statusText}`);
	}).then(json => {
		if (json.errorMessage) {
			errorExit(json.errorMessage);
		}
		checkbox('resource whitelist synced');
		checkbox('domains synced');
		n();
	}).catch(err => {
		errorExit(err);
	});
};

module.exports = sync;
