import jsonfile from 'jsonfile';
import File from '../file';

export default class Config extends File {
	constructor(path) {
		super(path);
		const config = jsonfile.readFileSync(path, {throws: false});
		this.config = config;
	}

	get() {
		return this.config;
	}

	getProjectId() {
		return this.config.projectId;
	}

	getResourceWhitelist() {
		return this.config.resourceWhitelist;
	}

	getDomains() {
		return this.config.domains;
	}

	getSiteDir() {
		return this.config.directory;
	}

	getStack() {
		return this.config.stack;
	}

	blinkloaderDir() {
		return process.cwd() + '/.blinkloader';
	}

	getSiteOptimizedDir() {
		return this.config.directory + '_optimized';
	}

	getSiteArchive() {
		return this.blinkloaderDir() + '/ar.zip';
	}

	getApiKey() {
		let key = this.config.apiKey;
		if (!key || key === '' || key === 'YOUR_API_KEY') {
			key = process.env.BLINKLOADER_API_KEY;
			if (!key) {
				key = '';
			}
		}
		return key;
	}

	getOptimizations() {
		return this.config.optimizations;
	}
}
