import path from 'path';
import oldfs from 'fs';
import fs from 'fs-extra';

export default class File {
	constructor(p) {
		this.path = this.dirName(p);
	}

	dirName(dir) {
		const absP = path.join(__dirname, dir);
		const splitted = absP.split('/');
		return splitted[splitted.length - 1];
	}

	getPath() {
		return this.path;
	}

	copyDir(old, newDir) {
		fs.copySync(old, newDir);
	}

	walkDir(dir) {
		const walkSync = (dir, filelist = []) => {
			fs.readdirSync(dir).forEach(file => {
				filelist = fs.statSync(path.join(dir, file)).isDirectory() ?
					walkSync(path.join(dir, file), filelist) :
					filelist.concat(path.join(dir, file));
			});
			return filelist;
		};
		return walkSync(dir);
	}

	getDirEntries(dir, files, extensions) {
		const dirName = this.dirName(dir);
		return files.filter(file => {
			const splitted = file.split('.');
			const ext = splitted[splitted.length - 1];
			if (extensions.indexOf(ext) === -1) {
				return false;
			}
			return true;
		}).map(file => {
			if (file.indexOf(dirName) === -1) {
				return null;
			}
			return file.slice(file.indexOf(dirName) + dirName.length, file.length);
		});
	}

	writeFile(file, content, cb) {
		oldfs.writeFile(path.join(process.cwd(), file), content, err =>
			err ? cb(err) : cb(null)
		);
	}

	removeFile(file, cb) {
		oldfs.unlink(path.join(process.cwd(), file), err => err ? cb(err) : cb(null));
	}

	removeDir(path, cb) {
		if (oldfs.existsSync(path)) {
			oldfs.readdirSync(path).forEach(file => {
				const curPath = path + '/' + file;
				if (oldfs.lstatSync(curPath).isDirectory()) {
					this.removeDir(curPath, () => {});
				} else {
					oldfs.unlinkSync(curPath);
				}
			});
			oldfs.rmdirSync(path);
		}
		if (cb) {
			cb();
		}
	}
}

