import checkAPIQuota from '../../../../src/commands/optimize/check-api-quota';
import initConfig from '../config-mock';

describe('check-api-quota stage test', () => {
	it('should errorExit if res.status != 200', (done) => {
		const res = {
			status: 404,
			statusText: "not found"
		};
		const json = {}
		const config = initConfig(res, json);
		checkAPIQuota(config)
			.catch(err => {
				expect(err).toBe('errorExit');
				done();
			})
	});

	it('should errorExit if json.errorMessage is returned', (done) => {
		const res = { status: 200 };
		const json = { errorMessage: "some error returned" }; 

		const config = initConfig(res, json);
		checkAPIQuota(config)
			.catch(err => {
				expect(err).toBe('errorExit');
				done();
			})
	});

	it('should errorExit if json.remains < 0', (done) => {
		const res = { status: 200 };
		const json = { remains: 0 };

		const config = initConfig(res, json);
		checkAPIQuota(config)
			.catch(err => { 
				expect(err).toBe('errorExit');
				done();
			})
	});

	it('should resolve config if json.remains > 0', (done) => {
		const res = { status: 200 };
		const json = { remains: 10 };

		const config = initConfig(res, json);
		checkAPIQuota(config)
			.then(c => {
				expect(c).toBe(config);
				done();
			})
	});
});
