import fs from 'fs';
import zlib from 'zlib';

import gzipAssets from '../../../../src/commands/optimize/gzip-assets';
import initConfig from '../config-mock';

describe('gzip-assets stage test', () => {
	it('should resolve if gzip is in the optimizations list', (done) => {
		const config = initConfig();	
		config.config.optimizations = [];
		
		gzipAssets(config).then(c => {
			expect(c).toBe(config);
			done();
		});

	});

	it('should resolve if file should not be gzipped', (done) => {
		const config = initConfig();	
		// file that should not be gzipped
		config.config.file = 'someFile.webm';
		
		gzipAssets(config).then(c => {
			expect(c).toBe(config);
			done();
		});
	});

	it('should reject if file does not exist', (done) => {
		const config = initConfig();	
		// file that should be gzipped
		config.config.file = 'someFile.jpg';
		
		gzipAssets(config).catch(err => {
			expect(err).toBe('error');
			done();
		});
	});

	it('should gzip file and resolve if file exist and should be gzipped', (done) => {
		const config = initConfig();	
		// file that should be gzipped
		fs.writeFileSync("./someFile.js", "console.log('hello and goodbye world');")
		config.config.file = './someFile.js';
		
		gzipAssets(config).then(c => {
			expect(c).toBe(config);

			zlib.gzip("console.log('hello and goodbye world');", (err, res) => {
				expect(res.data).toBe(fs.readFileSync('./someFile.js').data);
				fs.unlinkSync('./someFile.js')
				done();
			});
		});
	});
});
