import fs from 'fs';

import Config from '../../../src/utils/config';
import jsonfile from 'jsonfile';

describe('Config test', () => {
  // Set-up
  const testJson = {
    apiKey: 'YOUR_API_KEY',
    domains: [
      'example.com'
    ],
    stack: 'static-website-via-s3',
    directory: './static',
    ci: 'circle',
    cdn: true
  };

  let config;

  beforeAll(() => {
    jsonfile.writeFileSync('./blinkloader_test.json', testJson);
    config = new Config('./blinkloader_test.json');
  });


  it('should get object from a file', () => {
    expect(config.get()).toBeTruthy();
  });

  it('should return null if error reading file', () => {
    const config = new Config('./wrong.json');
    expect(config.get()).toBe(null);
  });

  it('should return `directory` field from testJson object', () => {
    expect(config.getSiteDir()).toBe('./static');
  });

  it('should return name of directory for optimized site', () => {
    expect(config.getSiteOptimizedDir()).toBe('./static_optimized');
  });

  it('should return an api-key', () => {
    expect(config.getApiKey()).toBe('');

    const keymock = 'some_api_key'

    process.env.BLINKLOADER_API_KEY = keymock;
    const config1 = new Config('./blinkloader_test.json');
    expect(config1.getApiKey()).toBe(keymock);

    process.env.BLINKLOADER_API_KEY = '';
    const config2 = new Config('./blinkloader_test.json');
    expect(config2.getApiKey()).toBe('');
  })

  // Teardown
  afterAll(() => {
    fs.unlink('./blinkloader_test.json', err => {
      if (err) {
        console.log(err);
      }
    });
  });
});
